@@ -8,10 +8,16 @@ class RawText:
     """Raw text extracted from the document."""
 
     pages: List[RawTextPage]
-    """Page the raw text was found on."""
+    """Pages of raw text content."""
 
     def __init__(self, raw_response: StringDict):
         self.pages = [RawTextPage(page) for page in raw_response.get("pages", [])]
 
     def __str__(self) -> str:
-        return "\n\n".join([page.content for page in self.pages])
+        """
+        Text content of all pages.
+
+        Each page is separated by 2 newline characters.
+        """
+        page_contents = "\n\n".join([page.content for page in self.pages])
+        return page_contents + "\n"
